@@ -5,6 +5,6 @@ use warnings;
 
 use CGI ':standard';
 
-print header;
+print header(-charset => 'utf-8');
 print "hello " . param('name');
 exit(param('exit') || 0);
